@@ -323,7 +323,7 @@ class ExportInventory:
 
         return dict_uvek
 
-    def write_lci(self, presamples, ecoinvent_compatibility, ecoinvent_version):
+    def write_lci(self, presamples, ecoinvent_compatibility, ecoinvent_version, forbidden_activities=None):
         """
         Return the inventory as a dictionary
         If if there several values for one exchange, uncertainty information is generated.
@@ -349,7 +349,6 @@ class ExportInventory:
             "straw pellets",
             "Biodiesel from cooking oil",
             "Straw bales | baling of straw",
-            "CO2 storage/natural gas, post, 200km pipeline, storage 1000m/2025",
             "drilling, deep borehole/m",
             "Sugar beet cultivation {RER} | sugar beet production Europe | Alloc Rec, U",
             "Refined Waste Cooking Oil {RER} | Refining of waste cooking oil Europe | Alloc Rec, U",
@@ -368,7 +367,6 @@ class ExportInventory:
             "heat exchanger, carbon dioxide capture process",
             "biogas upgrading - sewage sludge - amine scrubbing - best",
             "Hydrogen refuelling station, SMR",
-            "Hydrogen, gaseous, 700 bar, from SMR NG w/o CCS, at H2 fuelling station",
             "transformer and rectifier unit, for electrolyzer",
             "PEM electrolyzer, ACDC Converter",
             "carbon dioxide, captured from atmosphere",
@@ -391,15 +389,13 @@ class ExportInventory:
             "Buffer tank",
             "frequency converter, for diaphragm compressor",
             'Hydrogen, gaseous, 30 bar, from hard coal gasification and reforming, at coal gasification plant',
-            'Methanol distillation',
+            #'Methanol distillation',
             'CO2 storage/at H2 production plant, pre, pipeline 200km, storage 1000m',
-            'Syngas, RWGS, Production',
+            #'Syngas, RWGS, Production',
             'softwood forestry, mixed species, sustainable forest management, CF = -1',
             'hardwood forestry, mixed species, sustainable forest management, CF = -1',
             'Hydrogen, gaseous, 25 bar, from dual fluidised bed gasification of woody biomass with CCS, at gasification plant',
             'market for wood chips, wet, measured as dry mass, CF = -1',
-            'Hydrogen, gaseous, 700 bar, from electrolysis, at H2 fuelling station',
-            'Hydrogen, gaseous, 25 bar, from electrolysis',
             'Hydrogen, gaseous, 700 bar, from dual fluidised bed gasification of woody biomass with CCS, at H2 fuelling station',
             'SMR BM, HT+LT, + CCS (MDEA), 98 (average), digestate incineration, 26 bar',
             'Hydrogen, gaseous, 700 bar, from SMR of biogas, at H2 fuelling station',
@@ -407,14 +403,45 @@ class ExportInventory:
             'SMR BM, HT+LT, with digestate incineration, 26 bar',
             'Hydrogen, gaseous, 700 bar, from dual fluidised bed gasification of woody biomass, at H2 fuelling station',
             'Hydrogen, gaseous, 700 bar, from SMR of biogas with CCS, at H2 fuelling station',
-            'Hydrogen, gaseous, 700 bar, from SMR NG w CCS, at H2 fuelling station',
             'SMR NG + CCS (MDEA), 98 (average), 700 bar',
             'Hydrogen, gaseous, 25 bar, from dual fluidised bed gasification of woody biomass, at gasification plant',
-            'Methanol Synthesis',
-            'Diesel production, synthetic, Fischer Tropsch process',
-            'Gasoline production, synthetic, from methanol'
+            #'Methanol Synthesis',
+            #'Diesel production, synthetic, Fischer Tropsch process',
+            #'Gasoline production, synthetic, from methanol',
+            'Crude vegetable oil | oil mill: extraction of vegetable oil from rapeseed | Alloc Rec, U',
+            'biomethane from biogas upgrading - biowaste - amine scrubbing, best - with biogenic carbon uptake, lower bound C sequestration, digestate incineration',
+            'Plant oil from crude oil | refining of vegetable oil from oil palm|',
+            'ATR BM, with digestate incineration, 25 bar',
+            'Hydrogen, gaseous, 25 bar, from gasification of woody biomass in oxy-fired entrained flow gasifier, at gasification plant',
+            'Ethanol from wheat grains',
+            'Wheat grain cultivation, drying and storage {RER} | wheat grain production Europe | Alloc Rec, U',
+            'Hydrogen, gaseous, 700 bar, ATR of NG, with CCS, at H2 fuelling station',
+            'ATR BM + CCS (MDEA), 98 (average), with digestate incineration, 25 bar',
+            'SMR NG, 25 bar',
+            'Plant oil production | refining of crude vegetable oil from rapeseed| Alloc Rec, U',
+            'ethanol without biogas',
+            'Biodiesel from rapeseed oil',
+            'Hydrogen, gaseous, 700 bar, ATR of NG, at H2 fuelling station',
+            'Waste Cooking Oil',
+            'Carbon monoxide, from RWGS',
+            'Oil Palm Tree Cultivation {RER} | Fresh Fruit Bunches (FFBs) production | Alloc Rec, U',
+            'ATR NG, 25 bar',
+            'Rapeseed cultivation {RER} | rapeseed production Europe | Alloc Rec, U',
+            'Hydrogen, gaseous, 700 bar, from ATR of biogas with CCS, at H2 fuelling station',
+            'Hydrogen, gaseous, 25 bar, from gasification of woody biomass in oxy-fired entrained flow gasifier, with CCS, at gasification plant',
+            'SMR NG, 700 bar',
+            'Hydrogen, gaseous, 700 bar, from SMR of NG, with CCS, at H2 fuelling station',
+            'ATR NG + CCS (MDEA), 98 (average), 25 bar',
+            'Hydrogen, gaseous, 700 bar, from ATR of biogas, at H2 fuelling station',
+            'Biodiesel from palm oil',
+            'Hydrogen, gaseous, 700 bar, from SMR of NG, at H2 fuelling station',
+            'treatment of biowaste by anaerobic digestion, with biogenic carbon uptake, lower bound C sequestration, digestate incineration',
+            'Crude Palm Oil extraction from FFBs {RER} |oil mill|'
         ]
 
+        if isinstance(forbidden_activities, list):
+            activities_to_be_removed.extend(forbidden_activities)
+
         uvek_activities_to_remove = [
             "market for activated carbon, granular",
             "market for iodine",
@@ -632,7 +659,8 @@ class ExportInventory:
         ecoinvent_compatibility,
         ecoinvent_version,
         software_compatibility,
-        filename=None
+        filename=None,
+        forbidden_activities=None
     ):
         """
         Export an Excel file that can be consumed by the software defined in `software_compatibility`.
@@ -673,7 +701,7 @@ class ExportInventory:
                 os.makedirs(directory)
             filepath_export = os.path.join(directory, safe_name)
 
-        list_act = self.write_lci(False, ecoinvent_compatibility, ecoinvent_version)
+        list_act = self.write_lci(False, ecoinvent_compatibility, ecoinvent_version, forbidden_activities)
 
         if software_compatibility == "brightway2":
             data = []
@@ -1062,7 +1090,7 @@ class ExportInventory:
 
         return filepath_export
 
-    def write_lci_to_bw(self, presamples, ecoinvent_compatibility, ecoinvent_version):
+    def write_lci_to_bw(self, presamples, ecoinvent_compatibility, ecoinvent_version, forbidden_activities):
         """
         Return a LCIImporter object with the inventory as `data` attribute.
 
@@ -1071,14 +1099,14 @@ class ExportInventory:
         """
         if presamples == True:
             data, array = self.write_lci(
-                presamples, ecoinvent_compatibility, ecoinvent_version
+                presamples, ecoinvent_compatibility, ecoinvent_version, forbidden_activities
             )
             i = bw2io.importers.base_lci.LCIImporter(self.db_name)
             i.data = data
             return (i, array)
         else:
             data = self.write_lci(
-                presamples, ecoinvent_compatibility, ecoinvent_version
+                presamples, ecoinvent_compatibility, ecoinvent_version, forbidden_activities
             )
             i = bw2io.importers.base_lci.LCIImporter(self.db_name)
             i.data = data
