@@ -59,6 +59,7 @@ class CarModel:
         else:
             self.ecm = EnergyConsumptionModel(cycle=cycle, gradient=gradient)
 
+
     def __call__(self, key):
         """
         This method fixes a dimension of the `array` attribute given a powertrain technology selected.
@@ -757,12 +758,21 @@ class CarModel:
             "NMVOC direct emissions, urban",
             "NMVOC direct emissions, suburban",
             "NMVOC direct emissions, rural",
+            "Toluene direct emissions, urban",
+            "Toluene direct emissions, suburban",
+            "Toluene direct emissions, rural",
+            "Xylene direct emissions, urban",
+            "Xylene direct emissions, suburban",
+            "Xylene direct emissions, rural",
+            "Formaldehyde direct emissions, urban",
+            "Formaldehyde direct emissions, suburban",
+            "Formaldehyde direct emissions, rural",
+            "Acetaldehyde direct emissions, urban",
+            "Acetaldehyde direct emissions, suburban",
+            "Acetaldehyde direct emissions, rural",
             "Lead direct emissions, urban",
             "Lead direct emissions, suburban",
             "Lead direct emissions, rural",
-            "Sulfur dioxide direct emissions, urban",
-            "Sulfur dioxide direct emissions, suburban",
-            "Sulfur dioxide direct emissions, rural",
             "Dinitrogen oxide direct emissions, urban",
             "Dinitrogen oxide direct emissions, suburban",
             "Dinitrogen oxide direct emissions, rural",
@@ -772,6 +782,7 @@ class CarModel:
             "Benzene direct emissions, urban",
             "Benzene direct emissions, suburban",
             "Benzene direct emissions, rural",
+
         ]
 
         # Year index for EURO 6-d pollution class, starts in 2020
